#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pepino']

package_data = \
{'': ['*']}

setup(name='pepino',
      version='0.1',
      description='Esto no solo tiene pepinos sino mucha verdura',
      author='sashakile',
      author_email='saxa.kile@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
     )
